@@ -77,6 +77,7 @@ void xmlParse(TodoDB &outdb, vector<XML*>::const_iterator begin,
 					todo.priority = desymbolisePriority(attrib["priority"]);
 					todo.text = trim((*x.child().begin())->body());
 					todo.added = destringify<time_t>(attrib["time"]);
+					todo.db = &outdb;
 
 					for (vector<XML*>::const_iterator j = x.child().begin(); j != x.child().end(); ++j)
 						if ((*j)->name() == "comment") {
@@ -84,9 +85,43 @@ void xmlParse(TodoDB &outdb, vector<XML*>::const_iterator begin,
 							break;
 						}
 
-					xmlParse(outdb, x.child().begin(), x.child().end(), todo.child);
-
+					xmlParse(outdb, x.child().begin(), x.child().end(), *todo.child);
 					out.insert(todo);
+				} else if (x.name() == "link") {
+				TodoDB *newDb = new TodoDB();
+				Todo todo;
+				map<string, string> &attrib = *const_cast<map<string, string>* >(&x.attrib());
+
+					if (attrib.find("priority") == attrib.end() || attrib.find("filename") == attrib.end() || attrib.find("time") == attrib.end())
+						throw load_error("require 'priority', 'time', and 'filename' attributes for 'link' element");
+
+					try {
+						if (outdb.basepath == "" || attrib["filename"][0] == '/')
+							newDb->load(attrib["filename"]);
+						else
+							newDb->load(outdb.basepath + "/" + attrib["filename"]);
+						if (newDb->titleText == "") {
+							if (newDb->basepath == "")
+								todo.text = attrib["filename"];
+							else
+								todo.text = newDb->basepath.substr(newDb->basepath.rfind("/") + 1);
+						}
+						else
+							todo.text = newDb->titleText;
+
+						delete todo.child;
+
+						
+						todo.type = Todo::Link;
+						todo.child = &newDb->todo;
+						todo.priority = desymbolisePriority(attrib["priority"]);
+						todo.todofile = attrib["filename"];
+						todo.db = newDb;
+
+						out.insert(todo);
+					} catch (...) {
+						delete newDb;
+					}
 				} else
 				if (x.name() != "comment")
 					throw load_error("expected 'note' element, got '" + x.name() + "'");
@@ -133,47 +168,80 @@ map<string, string> const &attrib = x.attrib();
 	return true;
 }
 
-void xmlSave(multiset<Todo> const &todo, ostream &of, int ind) {
+void xmlSave(TodoDB const &db, multiset<Todo> const &todo, ostream &of, int ind) {
 	for (multiset<Todo>::const_iterator i = todo.begin(); i != todo.end(); i++) {
-		of	<< string(ind * 4, ' ') << "<note"
-			<< " priority=\"" << symbolisePriority((*i).priority) << "\""
-			<< " time=\"" << (*i).added << "\"";
-		if ((*i).done) {
-			of	<< " done=\"" << (*i).doneTime<< "\"";
-		}
-		of << ">" << endl;
-		of << string((ind + 1) * 4, ' ');
-		of << htmlify((*i).text) << endl;
-		if ((*i).comment != "") {
+		if (i->type == Todo::Link) {
+			of  << string(ind * 4, ' ') << "<link"
+			    << " filename=\"" << i->todofile << "\""
+				<< " priority=\"" << symbolisePriority(i->priority) << "\""
+				<< " time=\"" << i->added << "\""
+				<< "/>" << endl;
+
+			if (i->db)
+				i->db->save(i->todofile);
+
+			/* Restore the TODODB environment variable. */
+string envar = "TODODB=" + db.filename;
+
+			putenv(strdup(const_cast<char*>(envar.c_str())));
+
+		} else {
+			of	<< string(ind * 4, ' ') << "<note"
+				<< " priority=\"" << symbolisePriority((*i).priority) << "\""
+				<< " time=\"" << (*i).added << "\"";
+			if ((*i).done) {
+				of	<< " done=\"" << (*i).doneTime<< "\"";
+			}
+			of << ">" << endl;
 			of << string((ind + 1) * 4, ' ');
-			of << "<comment>" << endl;
-			of << string((ind + 2) * 4, ' ');
-			of << htmlify((*i).comment) << endl;
-			of << string((ind + 1) * 4, ' ');
-			of << "</comment>" << endl;
+			of << htmlify((*i).text) << endl;
+			if ((*i).comment != "") {
+				of << string((ind + 1) * 4, ' ');
+				of << "<comment>" << endl;
+				of << string((ind + 2) * 4, ' ');
+				of << htmlify((*i).comment) << endl;
+				of << string((ind + 1) * 4, ' ');
+				of << "</comment>" << endl;
+			}
+			xmlSave(db, *i->child, of, ind + 1);
+			of << string(ind * 4, ' ');
+			of << "</note>" << endl;
 		}
-		xmlSave((*i).child, of, ind + 1);
-		of << string(ind * 4, ' ');
-		of << "</note>" << endl;
 	}
 }
 
 bool xmlSave(TodoDB const &todo, string const &file) {
-ofstream of(file.c_str());
+	if (todo.isDirty())
+	{
+	ofstream of(file.c_str());
 
-	if (of.bad()) return false;
-	if (options.verbose > 1)
-		cout << "todo: saving to database '" << file << "'" << endl;
-	of	<< "<!-- Automagically generated by the ToDo program on " << dateToHuman(getCurrentDate()) << " -->" << endl;
-	of << "<todo version=\"" << VERSION << "\">" << endl;
-	if (todo.titleText != "")
-		of	<< "    <title>" << endl 
-			<< "        " << todo.titleText << endl
-			<< "    </title>" << endl;
-	xmlSave(todo.todo, of, 1);
-	of << "</todo>" << endl;
-	of.close();
-	return true;
+		if (of.bad()) return false;
+		if (options.verbose > 1)
+			cout << "todo: saving to database '" << file << "'" << endl;
+		of	<< "<!-- Automagically generated by the ToDo program on " << dateToHuman(getCurrentDate()) << " -->" << endl;
+		of << "<todo version=\"" << VERSION << "\">" << endl;
+		if (todo.titleText != "")
+			of	<< "    <title>" << endl 
+				<< "        " << todo.titleText << endl
+				<< "    </title>" << endl;
+
+		/* Set the TODODB environment variable. */
+	string envar = "TODODB=" + todo.filename;
+
+		putenv(strdup(const_cast<char*>(envar.c_str())));
+
+		xmlSave(todo, todo.todo, of, 1);
+		of << "</todo>" << endl;
+		of.close();
+		return true;
+	}
+	else
+	{
+	ofstream out("/dev/null");
+
+		xmlSave(todo, todo.todo, out, 1);
+		return false;
+	}
 }
 
 void binaryLoad(ifstream &in, int &n) {
@@ -190,7 +258,7 @@ char buffer[size + 1];
 	str = buffer;
 }
 
-void binaryLoad(ifstream &in, multiset<Todo> &out) {
+void binaryLoad(TodoDB &db, ifstream &in, multiset<Todo> &out) {
 int n;
 
 	binaryLoad(in, n);
@@ -203,7 +271,9 @@ int n;
 		binaryLoad(in, tmp); t.doneTime = tmp;
 		if (t.doneTime) t.done = true;
 		binaryLoad(in, t.text);
-		binaryLoad(in, t.child);
+		binaryLoad(db, in, *t.child);
+
+		t.db = &db;
 		out.insert(t);
 	}
 
@@ -229,7 +299,7 @@ string version;
 	binaryLoad(in, version);
 	checkVersion(version);
 	binaryLoad(in, out.titleText);
-	binaryLoad(in, out.todo);
+	binaryLoad(out, in, out.todo);
 	return true;
 }
 
@@ -252,7 +322,7 @@ void binarySave(ofstream &of, multiset<Todo> const &db) {
 		else
 			binarySave(of, 0);
 		binarySave(of, (*i).text);
-		binarySave(of, (*i).child);
+		binarySave(of, *i->child);
 	}
 }
 
@@ -260,6 +330,11 @@ bool binarySave(TodoDB const &in, string const &file) {
 ofstream of(file.c_str());
 
 	if (of.bad()) return false;
+
+string envar = "TODODB=" + in.filename;
+
+	putenv(strdup(const_cast<char*>(envar.c_str())));
+
 	of.write("TODO", 4);
 	binarySave(of, VERSION);
 	binarySave(of, in.titleText);
