@@ -3,11 +3,19 @@
 #include "Todo.h"
 
 Todo::Todo() : priority(None), done(false), added(0), doneTime(0), 
-	unfilteredchildren(0), filtered(true), in(0), 
-	parent(0) {
+	unfilteredchildren(0), filtered(true), type(Note), child(0), in(0), 
+	parent(0), db(0) {
+	
+	child = new multiset<Todo>;
+}
+
+Todo::Todo(const Todo &other) {
+	*this = other;
 }
 
 Todo::~Todo() {
+	if (type == Note && child != NULL)
+		delete child;
 }
 
 void Todo::incUnFilteredChildren() {
@@ -88,3 +96,36 @@ int Todo::operator < (Todo const &other) const {
 	}
 	return 0;
 }
+
+Todo &Todo::operator = (const Todo &other)
+{
+	if (this != &other)
+	{
+		priority = other.priority;
+		text = other.text;
+		todofile = other.todofile;
+		comment = other.comment;
+		done = other.done;
+		added = other.added;
+		doneTime = other.doneTime;
+
+		index = other.index;
+		unfilteredchildren = other.unfilteredchildren;
+		filtered = other.filtered;
+		type = other.type;
+
+		parent = other.parent;
+		db = other.db;
+
+		in = other.in;
+
+		if (type == Link)
+			child = other.child;
+		else {
+			child = new multiset<Todo>;
+			*child = *other.child;
+		}
+	}
+
+	return *this;
+}
