@@ -86,6 +86,7 @@ void TodoDB::operator () (Mode mode) {
 		case NotDone : triggerEvent("notdone"); notdone(); break;
 		case Title : triggerEvent("title"); edittitle(); break;
 		case Reparent : triggerEvent("reparent"); reparent(); break;
+		case Purge : triggerEvent("purge"); purge(); break;
 		default :
 			throw exception("unknown action?");
 		break;
@@ -957,6 +958,33 @@ ofstream out("TODO");
 		cout << info << "todo: generated TODO from current database" << normal << endl;
 }
 
+void TodoDB::purge() {
+time_t now = getCurrentDate();
+
+unsigned purged = purge(todo, now - options.purgeage * 86400);
+	if (options.verbose)
+		cout << info << "todo: purged " << purged << " items older than " << options.purgeage << " days" << endl;
+}
+
+unsigned TodoDB::purge(multiset<Todo> &todo, time_t age) {
+unsigned purged = 0;
+
+	for (multiset<Todo>::iterator i = todo.begin(); i != todo.end(); ++i) {
+		if (i->done && i->doneTime < age) {
+		multiset<Todo>::iterator last = i++;
+
+			todo.erase(last);
+			i->db->setDirty(true);
+			++purged;
+		} else {
+			if (i->child)
+				purged += purge(*i->child, age);
+			++i;
+		}
+	}
+	return purged;
+}
+
 void TodoDB::stats(multiset<Todo> const &todo, int ind) {
 }
 
