@@ -2,7 +2,7 @@
 #include <cstdlib>
 #include <cstring>
 #include <cstdio>
-#include <strstream>
+#include <sstream>
 #include <stdexcept>
 #include "support.h"
 #include "TodoDB.h"
@@ -18,7 +18,7 @@ static bool nukeonhit = false;
 Options options;
 
 Options::Options() :
-	verbose(0), mono(false), paranoid(false), global(false),
+	verbose(0), purgeage(0), mono(false), paranoid(false), global(false),
 	summary(false), timeout(false), comment(false),
 	database(".todo"),
 	priority(Todo::None),
@@ -200,7 +200,7 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono, ForceColour,
 	Database, GlobalDatabase, DateFormat, DisplayFormat,
 	VerboseDisplayFormat, VerboseGeneratedFormat,
 	GeneratedFormat, Sort, Paranoid, DatabaseLoaders, Backup,
-	Timeout, Format, UseFormat, DumpConfig, Exec, Echo, Stats };
+	Timeout, Format, UseFormat, DumpConfig, Exec, Echo, Stats, Purge };
 
 	args.addArgument('a', "add", CommandArgs::Optional);
 	args.setHelp('a', "Add a note (will prompt for a note if one is not supplied).");
@@ -276,6 +276,8 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono, ForceColour,
 	args.setHelp('s', "Toggle summary mode.");
 	args.addArgument(Timeout, "timeout", CommandArgs::Optional);
 	args.setHelp(Timeout, "Set the number of seconds between database displays and/or conform to this setting (see man page for more information).");
+	args.addArgument(Purge, "purge", CommandArgs::Optional);
+	args.setHelp(Purge, "Purge items marked as done. Optionally only purge completed items older than ARG days.");
 	args.addArgument(Exec, "exec", CommandArgs::Required);
 	args.addArgument(Echo, "echo", CommandArgs::Required);
 	args.addArgument(Stats, "stats");
@@ -334,6 +336,11 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono, ForceColour,
 					options.timeout = true;
 				}
 			break;
+			case Purge :
+				if (i.parameter())
+					options.purgeage = destringify<int>(i.parameter());
+				options.mode = TodoDB::Purge;
+			break;
 			case Exec :
 				if (options.verbose > 1)
 					cout << "todo: executing '" << i.parameter() << "'" << endl;
@@ -771,7 +778,7 @@ static bool rcvalid(string const &str) {
 		str == "summary" || str == "timeoutseconds" ||
 		str == "timeout" || str == "format" ||
 		str == "use-format" || str == "paranoid" || str == "exec" || 
-		str == "echo" || str == "comment";
+		str == "echo" || str == "comment" || str == "force-colour";
 }
 
 /*
@@ -814,7 +821,7 @@ vector<string> rcfile, out;
 
 		while (in.getline(line, 1024)) {
 		string str;
-		istrstream is(line);
+		istringstream is(line);
 
 			if (is >> str) {
 				if (str[0] == '#') continue;
@@ -837,7 +844,7 @@ vector<string> rcfile, out;
 					// multi-line event ?
 					if (str == "{") {
 						while (in.getline(line, 1024)) {
-						istrstream is(line);
+						istringstream is(line);
 
 							if (is >> str) {
 								if (str[0] == '#') continue;
