@@ -1,7 +1,7 @@
 #include "XML.h"
 
 bool XML::initialised = false;
-Lexer XML::xmlScan, XML::tagScan, XML::commentScan, XML::dataScan;
+Lexer XML::xmlScan, XML::tagScan, XML::commentScan, XML::dataScan, XML::processScan;
 
 #ifdef CRASH_SIGNAL
 Signal2<string const &, map<string, string> const &> XML::onElementBegin;
@@ -65,6 +65,10 @@ void XML::init() {
 		dataScan.addPattern(DataEnd, "]]>");
 		dataScan.addPattern(DataBody, "[\n\r]|.");
 
+		processScan.addPattern(ProcessBegin, "<\\?xml");
+		processScan.addPattern(ProcessBody, "\\?>|[^?][^>]");
+		processScan.addPattern(ProcessEnd, "\\?>");
+
 		initialised = true;
 	}
 }
